@@ -21,10 +21,12 @@ case "$SYS" in
       ld -shared -o $LIBNAME "$@";;
    OSF*)
       ld -shared -expect_unresolved '*' -o $LIBNAME "$@" -lc;;
-   Linux*|BSD/OS*|OpenBSD*)
+   Linux*|BSD/OS*|OpenBSD*|NetBSD*|GNU*)
       gcc -shared -o $LIBNAME -fPIC "$@";;
    FreeBSD*)
       ld -Bshareable -o $LIBNAME "$@" -lc;;
+   HP-UX*)
+      ld -b -o $LIBNAME "$@";;
    *)
       set -
       echo 1>&2 "don't know how to make libraries under $SYS"
