@@ -37,7 +37,7 @@ extern struct typinfo *high_typinfo;
 extern struct typinfo *low_typinfo;
 extern struct typinfo *free_typinfo;
 
-novalue free_struct_typinfo(struct typinfo *typ)  {
+void free_struct_typinfo(struct typinfo *typ)  {
 
    typ->bits = (unsigned int *)free_typinfo;
    free_typinfo = typ;
@@ -139,7 +139,7 @@ unsigned int n_types;
 /*
  * set_typ - set a particular type bit in a type bit vector.
  */
-novalue set_typ(type, bit)
+void set_typ(type, bit)
 #ifdef OptimizeType
 struct typinfo *type;
 #else					/* OptimizeType */
@@ -193,7 +193,7 @@ unsigned int bit;
 /*
  * clr_type - clear a particular type bit in a type bit vector.
  */
-novalue clr_typ(type, bit)
+void clr_typ(type, bit)
 #ifdef OptimizeType
 struct typinfo *type;
 #else					/* OptimizeType */
@@ -297,7 +297,7 @@ int typcd;
  * bitrange - determine the range of bit positions in a type bit vector
  *  that correspond to a type code from the data base.
  */
-novalue bitrange(typcd, frst_bit, last_bit)
+void bitrange(typcd, frst_bit, last_bit)
 int typcd;
 int *frst_bit;
 int *last_bit;
@@ -319,7 +319,7 @@ int *last_bit;
  * typcd_bits - set the bits of a bit vector corresponding to a type
  *  code from the data base.
  */
-novalue typcd_bits(typcd, typ)
+void typcd_bits(typcd, typ)
 int typcd;
 struct type *typ;
    {
@@ -458,7 +458,7 @@ unsigned int *typ;
  *   struct typinfo structure.
  */
 #ifdef OptimizeType
-novalue xfer_packed_types(type)
+void xfer_packed_types(type)
 struct typinfo *type;
 {
    unsigned int indx, mask;
@@ -623,7 +623,7 @@ int nsize;
  * and_bits_to_packed - performs a bitwise AND of two typinfo structures
  *    taking into account of packed or full bit representation.
  */
-novalue and_bits_to_packed(src, dest, size)
+void and_bits_to_packed(src, dest, size)
 struct typinfo *src;
 struct typinfo *dest;
 int size;
@@ -739,7 +739,7 @@ int pos;
  *     representation.
  */
 
-novalue clr_packed(src, nsize)
+void clr_packed(src, nsize)
 struct typinfo *src;
 int nsize;
 {
@@ -763,7 +763,7 @@ int nsize;
  *     to another.
  */
 
-novalue cpy_packed_to_packed(src, dest, nsize)
+void cpy_packed_to_packed(src, dest, nsize)
 struct typinfo *src;
 struct typinfo *dest;
 int nsize;
