@@ -19,9 +19,7 @@
  * is defined.
  */
 
-#if !EBCDIC
 #define tonum(c)	(isdigit(c) ? (c)-'0' : 10+(((c)|(040))-'a'))
-#endif					/* EBCDIC */
 
 /*
  * Prototypes for static functions.
@@ -38,14 +36,8 @@ int cnv_c_dbl(s, d)
 dptr s;
 double *d;
    {
-
-#ifdef LargeInts
-   tended	/* need to be tended if ston allocates largeint blocks */
-#endif					/* LargeInts */
-
-   struct descrip result, cnvstr;
+   tended struct descrip result, cnvstr;
    char sbuf[MaxCvtLen];
-
    union numeric numrc;
 
    type_case *s of {
@@ -108,12 +100,7 @@ int cnv_c_int(s, d)
 dptr s;
 C_integer *d;
    {
-
-#ifdef LargeInts
-   tended  /* tended since ston now allocates blocks */
-#endif						/* LargeInts */
-
-   struct descrip cnvstr, result;			/* not tended */
+   tended struct descrip cnvstr, result;
    union numeric numrc;
    char sbuf[MaxCvtLen];
 
@@ -261,12 +248,7 @@ int cnv_ec_int(s, d)
 dptr s;
 C_integer *d;
    {
-
-#ifdef LargeInts
-   tended  /* tended since ston now allocates blocks */
-#endif						/* LargeInts */
-
-   struct descrip cnvstr;			/* not tended */
+   tended struct descrip cnvstr;
    union numeric numrc;
    char sbuf[MaxCvtLen];
 
@@ -311,12 +293,7 @@ C_integer *d;
 int cnv_eint(s, d)
 dptr s, d;
    {
-
-#ifdef LargeInts
-   tended  /* tended since ston now allocates blocks */
-#endif						/* LargeInts */
-
-   struct descrip cnvstr;			/* not tended */
+   tended struct descrip cnvstr;
    char sbuf[MaxCvtLen];
    union numeric numrc;
 
@@ -350,7 +327,7 @@ dptr s, d;
          d->dword = D_Lrgint;
 	 BlkLoc(*d) = (union block *)numrc.big;
          return 1;
-#endif				/* LargeInts */
+#endif					/* LargeInts */
 
       default:
          return 0;
@@ -363,12 +340,7 @@ dptr s, d;
 int cnv_int(s, d)
 dptr s, d;
    {
-
-#ifdef LargeInts
-   tended   /* tended since ston now allocates blocks */
-#endif						/* LargeInts */
-
-   struct descrip cnvstr;			/* not tended */
+   tended struct descrip cnvstr;
    char sbuf[MaxCvtLen];
    union numeric numrc;
 
@@ -555,7 +527,7 @@ dptr s, d;
       return 1;
       }
    if (tmp_str(sbuf, s, &tmpstr)) {
-      for (l = 0; l < CsetSize; l++) 
+      for (l = 0; l < CsetSize; l++)
           cbuf->bits[l] = 0;
       d->dword = D_Cset;
       BlkLoc(*d) = (union block *)cbuf;
@@ -669,7 +641,7 @@ dptr s, d;
 /*
  * getdbl - return as a double the value inside a real block.
  */
-double getdbl(dp) 
+double getdbl(dp)
 dptr dp;
    {
    double d;
@@ -718,7 +690,7 @@ dptr d;
    }
 
 /*
- * dp_pnmcmp - do a string comparison of a descriptor to the procedure 
+ * dp_pnmcmp - do a string comparison of a descriptor to the procedure
  *   name in a pstrnm struct; used in call to qsearch().
  */
 int dp_pnmcmp(pne,dp)
@@ -1136,7 +1108,7 @@ double n;
 dptr dp;
 char *s;
    {
-   s++; 				/* leave room for leading zero */
+   s++;					/* leave room for leading zero */
    sprintf(s, "%.*g", Precision, n + dblZero);   /* format, avoiding -0 */
 
    /*
@@ -1175,7 +1147,7 @@ char *s;
       if (cs[i])
 	 for (j=i*IntBits, w=cs[i]; w; j++, w >>= 1)
 	    if (w & 01)
-	       *p++ = FromAscii((char)j);
+	       *p++ = (char)j;
       }
    *p = '\0';
 
