@@ -4,146 +4,6 @@
  *  [save], seek, stop, system, where, write, writes, [getch, getche, kbhit]
  */
 
-#if MICROSOFT || SCO_XENIX
-#define BadCode
-#endif					/* MICROSOFT || SCO_XENIX */
-
-#ifdef XENIX_386
-#define register
-#endif					/* XENIX_386 */
-/*
- * The following code is operating-system dependent [@fsys.01]. Include
- *  system-dependent files and declarations.
- */
-
-#if PORT
-   /* nothing to do */
-Deliberate Syntax Error
-#endif					/* PORT */
-
-#if AMIGA
-#if __SASC
-   /* Undefine macros from fcntl.h and stdlib.h that collide with
-      function names in this module. */
-#passthru #undef close
-#passthru #undef open
-#passthru #undef read
-#passthru #undef write
-#passthru #undef getenv
-#endif __SASC                           /* SASC  */
-extern FILE *popen(const char *, const char *);
-extern int pclose(FILE *);
-#endif AMIGA                            /* AMIGA */
-
-#if ATARI_ST || MSDOS || MVS || OS2 || UNIX || VM || VMS
-   /* nothing to do */
-#endif					/* ATARI_ST || MSDOS ... */
-
-#if MACINTOSH && MPW
-extern int MPWFlush(FILE *f);
-#define fflush(f) MPWFlush(f)
-#endif					/* MACINTOSH && MPW*/
-
-/*
- * End of operating-system specific code.
- */
-
-
-#ifdef MSWindows
-#ifdef FAttrib
-
-"fattrib(str, att) - get the attribute of a file "
-
-function{*} fattrib (fname, att[argc])
- 
-   if !cnv:C_string(fname) then
-        runerr(103, fname)
-
-   abstract {
-      return string ++ integer
-      }  
-
-   body {
-      tended char *s;
-      struct stat fs;
-#if UNIX
-      struct passwd *pwnam;
-      struct group  *grnam;
-#endif					/* UNIX */
-#if NT
-      HFILE hf;
-      OFSTRUCT of;
-      FILETIME ft1,ft2,ft3;
-      SYSTEMTIME st;
-#endif					/* NT */
-      int fd, i;
-      char *retval;
-      char *temp;
-      long l;
-   
-         if ( stat(fname, &fs) == -1 )
-            fail;
-	 for(i=0; i<argc; i++) {
-	    if (!cnv:C_string(att[i], s)) {
-	       runerr(103, att[i]);
-	       }
-         if ( !strcasecmp("size", s) ) {
-            suspend C_integer(fs.st_size);
-            }
-         else if ( !strcasecmp("status", s) ) {
-            temp = make_mode (fs.st_mode);
-	    l = strlen(temp);
-            Protect(retval = alcstr(temp,l), runerr(0));
-	    free(temp);
-            suspend string(l, retval); 
-            }
-#if UNIX
-         else if ( !strcasecmp("owner", s) ) {
-            pwnam = getpwuid (fs.st_uid);
-	    temp = pwnam->pw_name;
-	    l = strlen(temp);
-	    Protect(temp = alcstr(temp, l), runerr(0));
-            suspend string (l, temp);
-            }
-         else if ( !strcasecmp("group", s) ) {
-            grnam = getgrgid (fs.st_gid);
-	    temp = grnam->gr_name;
-	    l = strlen(temp);
-	    Protect(temp = alcstr(temp, l), runerr(0));
-            suspend string (l, temp);
-            }
-#endif					/* UNIX */
-         else if ( !strcasecmp("m_time", s) ) {
-	    temp = ctime(&(fs.st_mtime));
-	    l = strlen(temp);
-  	    if (temp[l-1] == '\n') l--;
-	    Protect(temp = alcstr(temp, l), runerr(0));
-            suspend string(l, temp);
-            }
-         else if ( !strcasecmp("a_time", s) ) {
-	    temp = ctime(&(fs.st_atime));
-	    l = strlen(temp);
-  	    if (temp[l-1] == '\n') l--;
-	    Protect(temp = alcstr(temp, l), runerr(0));
-            suspend string(l, temp);
-            }
-         else if ( !strcasecmp("c_time", s) ) {
-	    temp = ctime(&(fs.st_ctime));
-	    l = strlen(temp);
-  	    if (temp[l-1] == '\n') l--;
-	    Protect(temp = alcstr(temp, l), runerr(0));
-            suspend string(l, temp);
-            }
-         else {
-            runerr(160);
-            }
-      }
-      fail;
-   }
-end
-#endif					/* FAttrib */
-#endif					/* MSWindows */
-
 "close(f) - close file f."
 
 function{1} close(f)
@@ -164,52 +24,46 @@ function{1} close(f)
       if ((status & (Fs_Read | Fs_Write)) == 0)
 	 return f;			/* if already closed */
 
-      /*
-       * Close f, using fclose, pclose, or wclose as appropriate.
-       */
+      #ifdef Graphics
+         pollctr >>= 1;
+         pollctr++;
+         if (BlkLoc(f)->file.status & Fs_Window) {
+            /*
+             * Close a window.
+             */
+   	    BlkLoc(f)->file.status = Fs_Window;	/* clears read and write */
+   	    SETCLOSED((wbp) fp);
+   	    wclose((wbp) fp);
+   	    return f;
+   	 }
+      #endif				/* Graphics */
 
-#ifdef Graphics
-      /*
-       * Close window if windows are supported.
-       */
-
-      pollctr >>= 1;
-      pollctr++;
-      if (BlkLoc(f)->file.status & Fs_Window) {
-	 if (BlkLoc(f)->file.status != Fs_Window) { /* not already closed? */
-	    BlkLoc(f)->file.status = Fs_Window;
-	    SETCLOSED((wbp) fp);
-	    wclose((wbp) fp);
+      #ifdef ReadDirectory
+         if (BlkLoc(f)->file.status & Fs_Directory) {
+	    /*
+	     * Close a directory.
+	     */
+            closedir((DIR*) fp);
+	    BlkLoc(f)->file.status = 0;
+	    return f;
 	    }
-	 return f;
-	 }
-      else
-#endif					/* Graphics */
+      #endif				/* ReadDirectory */
+      
+      #ifdef Pipes
+         if (BlkLoc(f)->file.status & Fs_Pipe) {
+            /*
+             * Close a pipe.  (Returns pclose status, contrary to doc.)
+             */
+	    BlkLoc(f)->file.status = 0;
+	    return C_integer((pclose(fp) >> 8) & 0377);
+	    }
+      #endif				/* Pipes */
 
-#ifdef ReadDirectory
-      if (BlkLoc(f)->file.status & Fs_Directory)
-         closedir((DIR*) fp);
-      else
-#endif					/* ReadDirectory */
-
-#if AMIGA || ARM || OS2 || UNIX || VMS
       /*
-       * Close pipe if pipes are supported.
+       * Close a simple file.
        */
-
-      if (BlkLoc(f)->file.status & Fs_Pipe) {
-	 BlkLoc(f)->file.status = 0;
-	 return C_integer((pclose(fp) >> 8) & 0377);
-	 }
-      else
-#endif					/* AMIGA || ARM || OS2 || ... */
-
       fclose(fp);
       BlkLoc(f)->file.status = 0;
-
-      /*
-       * Return the closed file.
-       */
       return f;
       }
 end
@@ -250,7 +104,7 @@ function{0,1} getenv(s)
 	 Protect(p = alcstr(p,l),runerr(0));
 	 return string(l,p);
 	 }
-      else 				/* fail if not in environment */
+      else				/* fail if not in environment */
 	 fail;
 
       }
@@ -261,15 +115,10 @@ end
 "open(s1, s2, ...) - open file named s1 with options s2"
 " and attributes given in trailing arguments."
 function{0,1} open(fname, spec, attr[n])
-#else						/* Graphics */
-#ifdef OpenAttributes
-"open(fname, spec, attrstring) - open file fname with specification spec."
-function{0,1} open(fname, spec, attrstring)
-#else						/* OpenAttributes */
+#else					/* Graphics */
 "open(fname, spec) - open file fname with specification spec."
 function{0,1} open(fname, spec)
-#endif						/* OpenAttributes */
-#endif						/* Graphics */
+#endif					/* Graphics */
    declare {
       tended struct descrip filename;
       }
@@ -288,14 +137,6 @@ function{0,1} open(fname, spec)
    if !def:tmp_string(spec, letr) then
       runerr(103, spec)
 
-#ifdef OpenAttributes
-   /*
-    * Convert attrstr to a string, defaulting to "".
-    */
-   if !def:C_string(attrstring, emptystr) then
-      runerr(103, attrstring)
-#endif					/* OpenAttributes */
-
    abstract {
       return file
       }
@@ -317,32 +158,6 @@ function{0,1} open(fname, spec)
       tended struct b_lelem *bp;
 #endif					/* Graphics */
 
-/*
- * The following code is operating-system dependent [@fsys.02].  Make
- *  declarations as needed for opening files.
- */
-
-#if PORT
-Deliberate Syntax Error
-#endif					/* PORT */
-
-#if AMIGA || ATARI_ST || MACINTOSH || MSDOS || MVS || OS2 || VM
-   /* nothing is needed */
-#endif					/* AMIGA || ATARI_ST || ... */
-
-#if ARM
-      extern FILE *popen(const char *, const char *);
-      extern int pclose(FILE *);
-#endif					/* ARM */
-
-#if OS2 || UNIX || VMS
-      extern FILE *popen();
-#endif					/* OS2 || UNIX || VMS */
-
-/*
- * End of operating-system specific code.
- */
-
       /*
        * get a C string for the file name
        */
@@ -379,37 +194,21 @@ Deliberate Syntax Error
 	    case 'W':
 	       status |= Fs_Write;
 	       continue;
-
-#ifdef RecordIO
-	    case 's':
-	    case 'S':
-	       status |= Fs_Untrans;
-	       status |= Fs_Record;
-	       continue;
-#endif					/* RecordIO */
-
 	    case 't':
 	    case 'T':
 	       status &= ~Fs_Untrans;
-#ifdef RecordIO
-               status &= ~Fs_Record;
-#endif                                  /* RecordIO */
 	       continue;
-
 	    case 'u':
 	    case 'U':
 	       status |= Fs_Untrans;
-#ifdef RecordIO
-	       status &= ~Fs_Record;
-#endif					/* RecordIO */
 	       continue;
 
-#if AMIGA || ARM || OS2 || UNIX || VMS
+            #ifdef Pipes
 	    case 'p':
 	    case 'P':
 	       status |= Fs_Pipe;
 	       continue;
-#endif					/* AMIGA || ARM || OS2 || UNIX || VMS */
+            #endif			/* Pipes */
 
 	    case 'x':
 	    case 'X':
@@ -446,77 +245,15 @@ Deliberate Syntax Error
       else
 	 mode[0] = 'w';
 
-/*
- * The following code is operating-system dependent [@fsys.05].  Handle open
- *  modes.
- */
-
-#if PORT
       if ((status & (Fs_Read|Fs_Write)) == (Fs_Read|Fs_Write))
 	 mode[1] = '+';
-Deliberate Syntax Error
-#endif					/* PORT */
-
-#if AMIGA || ARM || UNIX || VMS
-      if ((status & (Fs_Read|Fs_Write)) == (Fs_Read|Fs_Write))
-	 mode[1] = '+';
-#endif					/* AMIGA || ARM || UNIX || VMS */
-
-#if ATARI_ST
-      if ((status & (Fs_Read|Fs_Write)) == (Fs_Read|Fs_Write)) {
-	 mode[1] = '+';
-	 mode[2] = ((status & Fs_Untrans) != 0) ? 'b' : 'a';
-	 }
-      else mode[1] = ((status & Fs_Untrans) != 0) ? 'b' : 'a';
-#endif					/* ATARI_ST */
-
-#if MACINTOSH
-      /* nothing to do */
-#endif					/* MACINTOSH */
-
-#if MSDOS || OS2
-      if ((status & (Fs_Read|Fs_Write)) == (Fs_Read|Fs_Write)) {
-	 mode[1] = '+';
-#if CSET2
-         /* we don't have the 't' in C Set/2 */
-         if ((status & Fs_Untrans) != 0) mode[2] = 'b';
-         } /* End of if - open file for reading or writing */
-      else if ((status & Fs_Untrans) != 0) mode[1] = 'b';
-#else					/* CSET2 */
-	 mode[2] = ((status & Fs_Untrans) != 0) ? 'b' : 't';
-	 }
-      else mode[1] = ((status & Fs_Untrans) != 0) ? 'b' : 't';
-#endif					/* CSET2 */
-#endif					/* MSDOS || OS2 */
-
-#if MVS || VM
-      if ((status & (Fs_Read|Fs_Write)) == (Fs_Read|Fs_Write)) {
-	 mode[1] = '+';
-	 mode[2] = ((status & Fs_Untrans) != 0) ? 'b' : 0;
-	 }
-      else mode[1] = ((status & Fs_Untrans) != 0) ? 'b' : 0;
-#endif					/* MVS || VM */
-
-/*
- * End of operating-system specific code.
- */
+      if ((status & Fs_Untrans) != 0)
+         strcat(mode, "b");
 
       /*
        * Open the file with fopen or popen.
        */
 
-#ifdef OpenAttributes
-#if SASC
-#ifdef RecordIO
-	 f = afopen(fnamestr, mode, status & Fs_Record ? "seq" : "",
-		    attrstring);
-#else					/* RecordIO */
-	 f = afopen(fnamestr, mode, "", attrstring);
-#endif					/* RecordIO */
-#endif					/* SASC */
-
-#else					/* OpenAttributes */
-
 #ifdef Graphics
       if (status & Fs_Window) {
 	 /*
@@ -548,14 +285,14 @@ Deliberate Syntax Error
 	 } else
 #endif					/* Graphics */
 
-#if AMIGA || ARM || OS2 || UNIX || VMS
+#ifdef Pipes
       if (status & Fs_Pipe) {
 	 if (status != (Fs_Read|Fs_Pipe) && status != (Fs_Write|Fs_Pipe))
 	    runerr(209, spec);
 	 f = popen(fnamestr, mode);
 	 }
       else
-#endif					/* AMIGA || ARM || OS2 || ... */
+#endif					/* Pipes */
 
          {
 #ifdef ReadDirectory
@@ -570,63 +307,14 @@ Deliberate Syntax Error
 #endif					/* ReadDirectory */
             f = fopen(fnamestr, mode);
          }
-#endif					/* OpenAttributes */
 
       /*
        * Fail if the file cannot be opened.
        */
       if (f == NULL) {
-#ifdef MSWindows
-         char tempbuf[512];
-	 *tempbuf = '\0';
-         if (strchr(fnamestr, '*') || strchr(fnamestr, '?')) {
-            /*
-	     * attempted to open a wildcard, do file completion
-	     */
-	    strcpy(tempbuf, fnamestr);
-            }
-	 else {
-            /*
-	     * check and see if the file was actually a directory
-	     */
-            struct stat fs;
-            if (stat(fnamestr, &fs) == -1) fail;
-	    if (fs.st_mode & _S_IFDIR) {
-	       strcpy(tempbuf, fnamestr);
-	       if (tempbuf[strlen(tempbuf)-1] != '\\')
-	          strcat(tempbuf, "\\");
-	       strcat(tempbuf, "*.*");
-	       }
-	    }
-         if (*tempbuf) {
-            FINDDATA_T fd;
-	    if (!FINDFIRST(tempbuf, &fd)) fail;
-            f = tmpfile();
-            if (f == NULL) fail;
-            do {
-               fprintf(f, "%s\n", FILENAME(&fd));
-               } while (FINDNEXT(&fd));
-            FINDCLOSE(&fd);
-            fflush(f);
-            fseek(f, 0, SEEK_SET);
-            if (f == NULL) fail;
-	    }
-#else					/* MSWindows */
 	 fail;
-#endif					/* MSWindows */
 	 }
 
-#if MACINTOSH
-#if MPW
-      {
-	 void SetFileToMPWText(const char *fname);
-
-	 if (status & Fs_Write)
-	    SetFileToMPWText(fnamestr);
-      }
-#endif					/* MPW */
-#endif					/* MACINTOSH */
-
       /*
        * Return the resulting file value.
        */
@@ -705,19 +393,6 @@ function{0,1} read(f)
          }
 #endif					/* ReadDirectory */
 
-#ifdef ConsoleWindow
-      /*
-       * if file is &input, then make sure our console is open and read
-       * from it, unless input redirected
-       */
-      if (fp == stdin
-           && !(ConsoleFlags & StdInRedirect)
-           ) {
-        fp = OpenConsole();
-        status = Fs_Window | Fs_Read | Fs_Write;
-        }
-
-#endif					/* ConsoleWindow */
       /*
        * Use getstrg to read a line from the file, failing if getstrg
        *  encounters end of file. [[ What about -2?]]
@@ -739,14 +414,8 @@ function{0,1} read(f)
 	 else
 #endif					/* Graphics */
 
-#ifdef RecordIO
-	 if ((slen = (status & Fs_Record ? getrec(sbuf, MaxReadStr, fp) :
-				   getstrg(sbuf, MaxReadStr, &BlkLoc(f)->file)))
-	     == -1) fail;
-#else					/* RecordIO */
 	 if ((slen = getstrg(sbuf, MaxReadStr, &BlkLoc(f)->file)) == -1)
 	    fail;
-#endif					/* RecordIO */
 
 	 /*
 	  * Allocate the string read and make s a descriptor for it.
@@ -813,19 +482,6 @@ function{0,1} reads(f,i)
 	 }
       BlkLoc(f)->file.status |= Fs_Reading;
 
-#ifdef ConsoleWindow
-      /*
-       * if file is &input, then make sure our console is open and read
-       * from it, unless input redirected
-       */
-      if (fp == stdin
-          && !(ConsoleFlags & StdInRedirect)
-          ) {
-        fp = OpenConsole();
-        status = Fs_Read | Fs_Write | Fs_Window;
-        }
-#endif					/* ConsoleWindow */
-
       /*
        * Be sure that a positive number of bytes is to be read.
        */
@@ -858,32 +514,6 @@ function{0,1} reads(f,i)
       Protect(StrLoc(s) = alcstr(NULL, i), runerr(0));
       StrLen(s) = 0;
 
-#if AMIGA
-#if LATTICE
-      /*
-       * The following code is special for Lattice 4.0 -- it was different
-       *  for Lattice 3.10.  It probably won't work correctly with other
-       *  C compilers.
-       */
-      if (IsInteractive(_ufbs[fileno(fp)].ufbfh)) {
-	 if ((i = read(fileno(fp),StrLoc(s),i)) <= 0)
-	    fail;
-	 StrLen(s) = i;
-	 /*
-	  * We may not have used the entire amount of storage we reserved.
-	  */
-	 nbytes = DiffPtrs(StrLoc(s) + i, strfree);
-	 if (nbytes < 0)
-	    EVVal(-nbytes, E_StrDeAlc);
-	 else
-	    EVVal(nbytes, E_String);
-	 strtotal += nbytes;
-	 strfree = StrLoc(s) + i;
-	 return s;
-	 }
-#endif					/* LATTICE */
-#endif					/* AMIGA */
-
 #ifdef Graphics
       pollctr >>= 1;
       pollctr++;
@@ -1043,36 +673,12 @@ function{0,1} seek(f,o)
 #endif					/* Graphics */
 
       if (o > 0) {
-/* fseek returns a non-zero value on error for CSET2, not -1 */
-#if CSET2
-	 if (fseek(fd, o - 1, SEEK_SET))
-#else
-	 if (fseek(fd, o - 1, SEEK_SET) == -1)
-#endif					/* CSET2 */
+	 if (fseek(fd, o - 1, SEEK_SET) != 0)
 	    fail;
 	 }
       else {
-
-#if CSET2
-/* unreliable seeking from the end in CSet/2 on a text stream, so
-   we will fixup seek-from-end to seek-from-beginning */
-	long size;
-	long save_pos;
-
-	/* save the position in case we have to reset it */
-	save_pos = ftell(fd);
-	/* seek to the end and get the file size */
-	fseek(fd, 0, SEEK_END);
-	size = ftell(fd);
-	/* try to accomplish the fixed-up seek */
-	if (fseek(fd, size + o, SEEK_SET)) {
-	   fseek(fd, save_pos, SEEK_SET);
-	   fail;
-	   }  /* End of if - seek failed, reset position */
-#else
-	 if (fseek(fd, o, SEEK_END) == -1)
+	 if (fseek(fd, o, SEEK_END) != 0)
 	    fail;
-#endif					/* CSET2 */
 	 }
       BlkLoc(f)->file.status &= ~(Fs_Reading | Fs_Writing);
       return f;
@@ -1168,21 +774,13 @@ end
       if ((k_errout.status & Fs_Write) == 0)
 	 runerr(213);
       else {
-#ifndef ConsoleWindow
 	 f = k_errout.fd;
-#else					/* ConsoleWindow */
-         f = (ConsoleFlags & StdErrRedirect) ? k_errout.fd : OpenConsole();
-#endif					/* ConsoleWindow */
 	 }
 #else					/* error_out */
       if ((k_output.status & Fs_Write) == 0)
 	 runerr(213);
       else {
-#ifndef ConsoleWindow
 	 f = k_output.fd;
-#else					/* ConsoleWindow */
-         f = (ConsoleFlags & StdOutRedirect) ? k_output.fd : OpenConsole();
-#endif					/* ConsoleWindow */
 	 }
 #endif					/* error_out */
       }
@@ -1200,10 +798,7 @@ end
       wputc('\n',(wbp)f);
    else
 #endif					/* Graphics */
-#ifdef RecordIO
-      if (!(status & Fs_Record))
-#endif					/* RecordIO */
-	 putc('\n', f);
+      putc('\n', f);
 #endif					/* nl */
 
    /*
@@ -1212,28 +807,12 @@ end
 #ifdef Graphics
    if (!(status & Fs_Window)) {
 #endif					/* Graphics */
-#ifdef RecordIO
-      if (status & Fs_Record)
-	 flushrec(f);
-#endif					/* RecordIO */
-
       if (ferror(f))
 	 runerr(214);
       fflush(f);
 
 #ifdef Graphics
       }
-#ifdef PresentationManager
-    /* must be writing to a window, then, if it is not the console,
-       we have to set the background mix mode of the character bundle 
-       back to LEAVEALONE so the background is no longer clobbered */
-    else if (f != ConsoleBinding) {
-      /* have to set the background mode back to leave-alone */
-      ((wbp)f)->context->charBundle.usBackMixMode = BM_LEAVEALONE;
-      /* force the reload on next use */
-      ((wbp)f)->window->charContext = NULL;
-      } /* End of else if - not the console window we're writing to */
-#endif					/* PresentationManager */
 #endif					/* Graphics */
 
 
@@ -1263,24 +842,7 @@ function {1} name(x[nargs])
 
    declare {
       FILE *f = NULL;
-      word status =
-#if terminate
-#ifndef ConsoleWindow
-	k_errout.status;
-#else					/* ConsoleWindow */
-        (ConsoleFlags & StdErrRedirect) ? k_errout.status : Fs_Read | Fs_Write | Fs_Window;
-#endif					/* ConsoleWindow */
-#else					/* terminate */
-#ifndef ConsoleWindow
-	k_output.status;
-#else					/* ConsoleWindow */
-        (ConsoleFlags & StdOutRedirect) ? k_output.status : Fs_Read | Fs_Write | Fs_Window;
-#endif					/* ConsoleWindow */
-#endif					/* terminate */
-
-#ifdef BadCode
-      struct descrip temp;
-#endif					/* BadCode */
+      word status = k_errout.status;
       }
 
 #if terminate
@@ -1342,14 +904,7 @@ function {1} name(x[nargs])
 			  }
 		     else {
 #endif					/* Graphics */
-#ifdef RecordIO
-			if (status & Fs_Record)
-			   flushrec(f);
-			else
-#endif					/* RecordIO */
-
-			   putc('\n', f);
-
+			putc('\n', f);
 			if (ferror(f))
 			   runerr(214);
 			fflush(f);
@@ -1359,16 +914,6 @@ function {1} name(x[nargs])
 		     }
 #endif					/* nl */
 
-#ifdef PresentationManager
-                 /* have to put the background mix back on the current file */
-                 if (f != NULL && (status & Fs_Window) && f != ConsoleBinding) {
-                   /* set the background back to leave-alone */
-                   ((wbp)f)->context->charBundle.usBackMixMode = BM_LEAVEALONE;
-                   /* unload the context from this window */
-                   ((wbp)f)->window->charContext = NULL;
-                   }
-#endif					/* PresentationManager */
-
 		  /*
 		   * Switch the current file to the file named by the current
 		   * argument providing it is a file.
@@ -1377,24 +922,6 @@ function {1} name(x[nargs])
 		  if ((status & Fs_Write) == 0)
 		     runerr(213, x[n]);
 		  f = BlkLoc(x[n])->file.fd;
-#ifdef ConsoleWindow
-                  if ((f == stdout && !(ConsoleFlags & StdOutRedirect)) ||
-                      (f == stderr && !(ConsoleFlags & StdErrRedirect))) {
-                     f = OpenConsole();
-                     status = Fs_Read | Fs_Write | Fs_Window;
-                     }
-#endif					/* ConsoleWindow */
-#ifdef PresentationManager
-                  if (status & Fs_Window) {
-                     /*
-		      * have to set the background to overpaint - the one
-                      * difference between DrawString and write(s)
-		      */
-                    ((wbp)f)->context->charBundle.usBackMixMode = BM_OVERPAINT;
-                    /* unload the context from the window so it will be reloaded */
-                    ((wbp)f)->window->charContext = NULL;
-                    }
-#endif					/* PresentationManager */
 		  }
 	       else {
 		  /*
@@ -1412,14 +939,9 @@ function {1} name(x[nargs])
 		     wputstr((wbp)f, StrLoc(t), StrLen(t));
 		  else
 #endif					/* Graphics */
-#ifdef RecordIO
-		     if ((status & Fs_Record ? putrec(f, &t) :
-					     putstr(f, &t)) == Failed)
-#else					/* RecordIO */
-		     if (putstr(f, &t) == Failed) {
-#endif					/* RecordIO */
-			runerr(214, x[n]);
-			}
+		  if (putstr(f, &t) == Failed) {
+		     runerr(214, x[n]);
+		     }
 		  }
 	       }
 
@@ -1447,7 +969,7 @@ function{0,1} getch()
       i = getch();
       if (i<0 || i>255)
 	 fail;
-      return string(1, (char *)&allchars[FromAscii(i) & 0xFF]);
+      return string(1, (char *)&allchars[i & 0xFF]);
       }
 end
 
@@ -1462,7 +984,7 @@ function{0,1} getche()
       i = getche();
       if (i<0 || i>255)
 	 fail;
-      return string(1, (char *)&allchars[FromAscii(i) & 0xFF]);
+      return string(1, (char *)&allchars[i & 0xFF]);
       }
 end
 
@@ -1491,56 +1013,11 @@ function{0,1} chdir(s)
       return null
       }
    inline {
-
-/*
- * The following code is operating-system dependent [@fsys.01].
- *  Change directory.
- */
-
-#if PORT
-   Deliberate Syntax Error
-#endif					/* PORT */
-
-#if ARM || MACINTOSH || MVS || VM
-      runerr(121);
-#endif					/* ARM || MACINTOSH ... */
-
-#if AMIGA || ATARI_ST || MSDOS || OS2 || UNIX || VMS
-   #if NT
-      int nt_chdir(char *);
-      if (nt_chdir(s) != 0)
-	 fail;
-   #else					/* NT */
       if (chdir(s) != 0)
-	 fail;
-   #endif					/* NT */
+         fail;
       return nulldesc;
-#endif					/* AMIGA || ATARI_ST || MSDOS || ... */
-
-/*
- * End of operating-system specific code.
- */
    }
 end
-
-#if NT
-#ifdef MSWindows
-char *getenv(char *s)
-{
-static char tmp[1537];
-DWORD rv;
-rv = GetEnvironmentVariable(s, tmp, 1536);
-if (rv > 0) return tmp;
-return NULL;
-}
-#endif					/* MSWindows */
-
-#passthru #include <direct.h>
-int nt_chdir(char *s)
-{
-    return chdir(s);
-}
-#endif					/* NT */
 
 "delay(i) - delay for i milliseconds."
 
@@ -1589,16 +1066,11 @@ function{1} flush(f)
 #ifdef Graphics
       pollctr >>= 1;
       pollctr++;
-
-#ifndef PresentationManager
-      if (BlkLoc(f)->file.status & Fs_Window)
-	 wflush((wbp)fp);
-      else
-#else
-       if (!(BlkLoc(f)->file.status & Fs_Window))
-#endif					/* PresentationManager */
-#endif					/* Graphics */
+      if (!(BlkLoc(f)->file.status & Fs_Window))
 	 fflush(fp);
+#else					/* Graphics */
+      fflush(fp);
+#endif					/* Graphics */
 
       /*
        * Return the flushed file.
@@ -1606,3 +1078,70 @@ function{1} flush(f)
       return f;
       }
 end
+
+#ifdef FAttrib
+
+"fattrib(str, att) - get the attribute of a file "
+
+function{*} fattrib (fname, att[argc])
+
+   if !cnv:C_string(fname) then
+        runerr(103, fname)
+
+   abstract {
+      return string ++ integer
+      }
+
+   body {
+      tended char *s;
+      struct stat fs;
+      int fd, i;
+      char *retval;
+      char *temp;
+      long l;
+
+         if ( stat(fname, &fs) == -1 )
+            fail;
+	 for(i=0; i<argc; i++) {
+	    if (!cnv:C_string(att[i], s)) {
+	       runerr(103, att[i]);
+	       }
+         if ( !strcasecmp("size", s) ) {
+            suspend C_integer(fs.st_size);
+            }
+         else if ( !strcasecmp("status", s) ) {
+            temp = make_mode (fs.st_mode);
+	    l = strlen(temp);
+            Protect(retval = alcstr(temp,l), runerr(0));
+	    free(temp);
+            suspend string(l, retval);
+            }
+         else if ( !strcasecmp("m_time", s) ) {
+	    temp = ctime(&(fs.st_mtime));
+	    l = strlen(temp);
+	    if (temp[l-1] == '\n') l--;
+	    Protect(temp = alcstr(temp, l), runerr(0));
+            suspend string(l, temp);
+            }
+         else if ( !strcasecmp("a_time", s) ) {
+	    temp = ctime(&(fs.st_atime));
+	    l = strlen(temp);
+	    if (temp[l-1] == '\n') l--;
+	    Protect(temp = alcstr(temp, l), runerr(0));
+            suspend string(l, temp);
+            }
+         else if ( !strcasecmp("c_time", s) ) {
+	    temp = ctime(&(fs.st_ctime));
+	    l = strlen(temp);
+	    if (temp[l-1] == '\n') l--;
+	    Protect(temp = alcstr(temp, l), runerr(0));
+            suspend string(l, temp);
+            }
+         else {
+            runerr(205, att[i]);
+            }
+      }
+      fail;
+   }
+end
+#endif					/* FAttrib */
