@@ -17,25 +17,15 @@ static void xtrace
 /*
  * tracebk - print a trace of procedure calls.
  */
-#ifdef PresentationManager
-/* have to add COMPILER support too */
-void tracebk(void *foo, dptr argp, HWND hwndMLE)
-#else					/* PresentationManager */
-void tracebk(lcl_pfp, argp)
 
 #if COMPILER
-struct p_frame *lcl_pfp;
-#else					/* COMPILER */
-struct pf_marker *lcl_pfp;
-#endif					/* COMPILER */
 
+void tracebk(lcl_pfp, argp)
+struct p_frame *lcl_pfp;
 dptr argp;
-#endif					/* PresentationManager */
    {
    struct b_proc *cproc;
 
-#if COMPILER
-
    struct debug *debug;
    word nparam;
 
@@ -46,9 +36,16 @@ dptr argp;
    cproc = debug->proc;
    xtrace(cproc, (word)abs((int)cproc->nparam), argp, debug->old_line,
       debug->old_fname);
+   }
 
 #else					/* COMPILER */
 
+void tracebk(lcl_pfp, argp)
+struct pf_marker *lcl_pfp;
+dptr argp;
+   {
+   struct b_proc *cproc;
+
    struct pf_marker *origpfp = pfp;
    dptr arg;
    inst cipc;
@@ -68,12 +65,8 @@ dptr argp;
     */
 
    while (pfp) {
-#ifdef PresentationManager
-      /* point at the beginning of the string */
-      ConsoleStringBufPtr = ConsoleStringBuf;
-#endif					/* PresentationManager */
       arg = &((dptr)pfp)[-(pfp->pf_nargs) - 1];
-      cproc = (struct b_proc *)BlkLoc(arg[0]);    
+      cproc = (struct b_proc *)BlkLoc(arg[0]);
       /*
        * The ipc in the procedure frame points after the "invoke n".
        */
@@ -83,30 +76,19 @@ dptr argp;
 
       xtrace(cproc, pfp->pf_nargs, &arg[0], findline(cipc.opnd),
          findfile(cipc.opnd));
-#ifdef PresentationManager
-      /* insert the text in the MLE */
-      WinSendMsg(hwndMLE, MLM_INSERT, MPFROMP(ConsoleStringBuf), (MPARAM)0);
-#endif					/* PresentationManager */
       /*
        * On the last call, show both the call and the offending expression.
        */
       if (pfp == origpfp) {
-#ifdef PresentationManager
-         /* make sure we are at the beginning of the buffer */
-         ConsoleStringBufPtr = ConsoleStringBuf;
          ttrace();
-         /* add it to the MLE */
-         WinSendMsg(hwndMLE, MLM_INSERT, MPFROMP(ConsoleStringBuf), (MPARAM)0);
-#else					/* PresentationManager */
-         ttrace();
-#endif					/* PresentationManager */
          break;
          }
- 
+
       pfp = (struct pf_marker *)(pfp->pf_efp);
       }
-#endif					/* COMPILER */
    }
+
+#endif					/* COMPILER */
 
 /*
  * xtrace - procedure *bp is being called with nargs arguments, the first
@@ -120,9 +102,6 @@ int pline;
 char *pfile;
    {
 
-#ifndef PresentationManager 
-   fprintf(stderr, "   ");
-#endif					/* PresentationManager */
    if (bp == NULL)
       fprintf(stderr, "????");
    else {
@@ -145,7 +124,7 @@ char *pfile;
           }
        putc(')', stderr);
        }
-	 
+
    if (pline != 0)
       fprintf(stderr, " from line %d in %s", pline, pfile);
    putc('\n', stderr);
@@ -235,7 +214,7 @@ int get_name(dp1,dp0)
             }
          else
             syserr("name: unknown integer keyword variable");
-            
+
       kywdevent:
 #ifdef MultiThread
          if (VarLoc(*dp1) == &curpstate->eventsource) {
@@ -253,7 +232,7 @@ int get_name(dp1,dp0)
          else
 #endif					/* MultiThread */
             syserr("name: unknown event keyword variable");
-            
+
       kywdwin: {
          StrLen(*dp0) = 7;
          StrLoc(*dp0) = "&window";
@@ -281,7 +260,7 @@ int get_name(dp1,dp0)
              */
             dp = VarLoc(*dp1);		 /* get address of variable */
             if (InRange(globals,dp,eglobals)) {
-               *dp0 = gnames[dp - globals]; 		/* global */
+               *dp0 = gnames[dp - globals];		/* global */
 	       return GlobalName;
 	       }
             else if (InRange(statics,dp,estatics)) {
@@ -310,7 +289,7 @@ int get_name(dp1,dp0)
             blkptr = (union block *)VarLoc(*dp1);
             varptr = (dptr)((word *)VarLoc(*dp1) + Offset(*dp1));
             switch ((int)BlkType(blkptr)) {
-               case T_Lelem: 		/* list */
+               case T_Lelem:		/* list */
                   i = varptr - &blkptr->lelem.lslots[blkptr->lelem.first] + 1;
                   if (i < 1)
                      i += blkptr->lelem.nslots;
@@ -332,7 +311,7 @@ int get_name(dp1,dp0)
                   Protect(StrLoc(*dp0) = alcstr(sbuf,i), return Error);
                   StrLen(*dp0) = i;
                   break;
-               case T_Record: 		/* record */
+               case T_Record:		/* record */
                   i = varptr - blkptr->record.fields;
                   proc = &blkptr->record.recdesc->proc;
 
@@ -349,7 +328,7 @@ int get_name(dp1,dp0)
                   Protect(StrLoc(*dp0) = alcstr(sbuf,i), return Error);
                   StrLen(*dp0) = i;
                   break;
-               case T_Telem: 		/* table */
+               case T_Telem:		/* table */
                   t = keyref(blkptr,dp0);
                   if (t == Error)
                       return Error;
@@ -357,9 +336,9 @@ int get_name(dp1,dp0)
                default:		/* none of the above */
 #ifdef EventMon
                   *dp0 = emptystr;
-#else                                   /* EventMon */
+#else					/* EventMon */
                   syserr("name: invalid structure reference");
-#endif                                  /* EventMon */
+#endif					/* EventMon */
 
                }
            }
@@ -377,7 +356,7 @@ int get_name(dp1,dp0)
    proc = PFDebug(*pfp)->proc; /* get address of procedure block */
    putstr(stderr, &proc->pname);
 #enddef
- 
+
 /*
  * ctrace - a procedure is being called; produce a trace message.
  */
@@ -465,7 +444,7 @@ static int keyref(bp, dp)
    int len;
 
    if (getimage(&(bp->telem.tref),dp) == Error)
-      return Error;	
+      return Error;
 
    /*
     * Allocate space, and copy the image surrounded by "table_n[" and "]"
@@ -558,27 +537,14 @@ int l;
    int i;
 
    i = (int)strlen(f);
-
-#if MVS
-   while (i > 22) {
-#else					/* MVS */
    while (i > 13) {
-#endif					/* MVS */
       f++;
       i--;
       }
    if (l > 0)
-
-#if MVS
-      fprintf(stderr, "%-22s: %4d  ",f, l);
-   else
-      fprintf(stderr, "                      :      ");
-#else					/* MVS */
       fprintf(stderr, "%-13s: %4d  ",f, l);
    else
       fprintf(stderr, "             :       ");
-#endif					/* MVS */
-
    }
 
 /*
@@ -609,11 +575,6 @@ static void ttrace()
    {
    struct b_proc *bp;
    word nargs;
-
-#ifndef PresentationManager
-   fprintf(stderr, "   ");
-#endif					/* PresentationManager */
-
    switch ((int)lastop) {
 
       case Op_Keywd:
@@ -649,48 +610,20 @@ static void ttrace()
       case Op_Subsc:
          putc('{', stderr);
          outimage(stderr, ++xargp, 0);
-
-#if EBCDIC != 1
          putc('[', stderr);
-#else					/* EBCDIC != 1 */
-         putc('$', stderr);
-         putc('<', stderr);
-#endif					/* EBCDIC != 1 */
-
          outimage(stderr, ++xargp, 0);
-
-#if EBCDIC != 1
          putc(']', stderr);
-#else					/* EBCDIC != 1 */
-         putc('$', stderr);
-         putc('>', stderr);
-#endif					/* EBCDIC != 1 */
-
          putc('}', stderr);
          break;
 
       case Op_Sect:
          putc('{', stderr);
          outimage(stderr, ++xargp, 0);
-
-#if EBCDIC != 1
          putc('[', stderr);
-#else					/* EBCDIC != 1 */
-         putc('$', stderr);
-         putc('<', stderr);
-#endif					/* EBCDIC != 1 */
-
          outimage(stderr, ++xargp, 0);
          putc(':', stderr);
          outimage(stderr, ++xargp, 0);
-
-#if EBCDIC != 1
          putc(']', stderr);
-#else					/* EBCDIC != 1 */
-         putc('$', stderr);
-         putc('>', stderr);
-#endif					/* EBCDIC != 1 */
-
          putc('}', stderr);
          break;
 
@@ -736,15 +669,9 @@ static void ttrace()
          break;
 
       case Op_Llist:
-
-#if EBCDIC != 1
          fprintf(stderr,"[ ... ]");
-#else					/* EBCDIC != 1 */
-         fputs("$< ... $>", stderr);
-#endif					/* EBCDIC != 1 */
          break;
 
-   
       default:
 
          bp = opblks[lastop];
@@ -757,20 +684,17 @@ static void ttrace()
             putc(' ', stderr);
             putstr(stderr, &(bp->pname));
             putc(' ', stderr);
-   	    }
+	    }
          else
 oneop:
          putstr(stderr, &(bp->pname));
          outimage(stderr, ++xargp, 0);
          putc('}', stderr);
       }
-	 
+
    if (ipc.opnd != NULL)
       fprintf(stderr, " from line %d in %s", findline(ipc.opnd),
          findfile(ipc.opnd));
-#ifndef PresentationManager
-   putc('\n', stderr);
-#endif					/* PresentationManager */
    fflush(stderr);
    }
 
@@ -1060,7 +984,7 @@ int xdisp(fp,dp,count,f)
    nglobals = eglobals - globals;
 #endif					/* COMPILER */
 
-   indices = (word *)malloc((msize)nglobals * sizeof(word));
+   indices = (word *)malloc(nglobals * sizeof(word));
    if (indices == NULL)
       return Failed;
    else {
