@@ -1,7 +1,7 @@
 /*
  * File: rmisc.r
  *  Contents: deref, eq, getvar, hash, outimage,
- *  qtos, pushact, popact, topact, [dumpact], 
+ *  qtos, pushact, popact, topact, [dumpact],
  *  findline, findipc, findfile, doimage, getimage
  *  printable, sig_rsm, cmd_line, varargs.
  *
@@ -18,7 +18,7 @@ static void	printimage	(FILE *f,int c,int q);
 static char *	csname		(dptr dp);
 
 
-/* 
+/*
  * eq - compare two Icon strings for equality
  */
 int eq(d1, d2)
@@ -32,7 +32,7 @@ dptr d1, d2;
 	s1 = StrLoc(*d1);
 	s2 = StrLoc(*d2);
 	for (i = 0; i < StrLen(*d1); i++)
-	   if (*s1++ != *s2++) 
+	   if (*s1++ != *s2++)
 	      return 0;
 	return 1;
 }
@@ -53,7 +53,7 @@ int getvar(s,vp)
 #if COMPILER
    struct descrip sdp;
 
-   if (!debug_info) 
+   if (!debug_info)
       fatalerr(402,NULL);
 
    StrLoc(sdp) = s;
@@ -145,7 +145,7 @@ int getvar(s,vp)
     *  parameters, and static names in each Icon procedure frame on the
     *  stack. If not found among the locals, check the global variables.
     *  If a variable with name is found, variable() returns a variable
-    *  descriptor that points to the corresponding value descriptor. 
+    *  descriptor that points to the corresponding value descriptor.
     *  If no such variable exits, it fails.
     */
 
@@ -164,7 +164,7 @@ int getvar(s,vp)
 #else					/* COMPILER */
    bp = (struct b_proc *)BlkLoc(*dp);	/* get address of procedure block */
 #endif					/* COMPILER */
-   
+
    np = bp->lnames;		/* Check the formal parameter names. */
 
    for (i = abs((int)bp->nparam); i > 0; i--) {
@@ -297,7 +297,7 @@ dptr dp;
 	    {
 	    struct b_bignum *b = &BlkLoc(*dp)->bignumblk;
 
-	    i = ((b->lsd - b->msd) << 16) ^ 
+	    i = ((b->lsd - b->msd) << 16) ^
 		(b->digits[b->msd] << 8) ^ b->digits[b->lsd];
 	    }
 	    break;
@@ -349,7 +349,7 @@ dptr dp;
          case T_Record:
             i = (13255 * BlkLoc(*dp)->record.id) >> 10;
             break;
- 
+
 	 case T_Proc:
 	    dp = &(BlkLoc(*dp)->proc.pname);
 	    goto hashstring;
@@ -594,23 +594,9 @@ int noimage;
             }
 
          if (bp->tvsubs.sslen == 1)
-
-#if EBCDIC != 1
             fprintf(f, "[%ld]", (long)bp->tvsubs.sspos);
-#else					/* EBCDIC != 1 */
-
-            fprintf(f, "$<%ld$>", (long)bp->tvsubs.sspos);
-#endif					/* EBCDIC != 1 */
-
          else
-
-#if EBCDIC != 1
             fprintf(f, "[%ld+:%ld]", (long)bp->tvsubs.sspos,
-
-#else					/* EBCDIC != 1 */
-            fprintf(f, "$<%ld+:%ld$>", (long)bp->tvsubs.sspos,
-#endif					/* EBCDIC != 1 */
-
                (long)bp->tvsubs.sslen);
 
          if (Qual(*dp)) {
@@ -632,22 +618,9 @@ int noimage;
 	 tdp.dword = D_Table;
 	 BlkLoc(tdp) = bp->tvtbl.clink;
          outimage(f, &tdp, noimage);
-
-#if EBCDIC != 1
          putc('[', f);
-#else					/* EBCDIC != 1 */
-         putc('$', f);
-         putc('<', f);
-#endif					/* EBCDIC != 1 */
-
          outimage(f, &bp->tvtbl.tref, noimage);
-
-#if EBCDIC != 1
          putc(']', f);
-#else					/* EBCDIC != 1 */
-         putc('$', f);
-         putc('>', f);
-#endif					/* EBCDIC != 1 */
          }
 
       kywdint: {
@@ -698,10 +671,10 @@ int noimage;
          outimage(f, VarLoc(*dp), noimage);
          }
 
-      default: { 
+      default: {
          if (is:variable(*dp)) {
             /*
-             * *d is a variable.  Print "variable =", dereference it, and 
+             * *d is a variable.  Print "variable =", dereference it, and
              *  call outimage to handle the value.
              */
             fprintf(f, "(variable = ");
@@ -760,36 +733,19 @@ int c, q;
       case '\b':			/* backspace */
          fprintf(f, "\\b");
          return;
-
-#if !EBCDIC
       case '\177':			/* delete */
-#else					/* !EBCDIC */
-      case '\x07':
-#endif					/* !EBCDIC */
-
          fprintf(f, "\\d");
          return;
-#if !EBCDIC
       case '\33':			/* escape */
-#else					/* !EBCDIC */
-      case '\x27':
-#endif					/* !EBCDIC */
          fprintf(f, "\\e");
          return;
       case '\f':			/* form feed */
          fprintf(f, "\\f");
          return;
-      case LineFeed:			/* new line */
+      case '\n':			/* newline (line feed) */
          fprintf(f, "\\n");
          return;
-
-#if EBCDIC == 1
-      case '\x25':                      /* EBCDIC line feed */
-         fprintf(f, "\\l");
-         return;
-#endif					/* EBCDIC == 1 */
-
-      case CarriageReturn:		/* carriage return */
+      case '\r':			/* carriage return */
          fprintf(f, "\\r");
          return;
       case '\t':			/* horizontal tab */
@@ -799,7 +755,7 @@ int c, q;
          fprintf(f, "\\v");
          return;
       default:				/* hex escape sequence */
-         fprintf(f, "\\x%02x", ToAscii(c & 0xff));
+         fprintf(f, "\\x%02x", c & 0xff);
          return;
       }
    }
@@ -833,13 +789,7 @@ int noimage;
     *  list, produce the first ListLimit/2 elements, an ellipsis, and the
     *  last ListLimit elements.
     */
-
-#if EBCDIC != 1
    fprintf(f, "list_%ld = [", (long)lp->id);
-#else					/* EBCDIC != 1 */
-   fprintf(f, "list_%ld = $<", (long)lp->id);
-#endif				/* EBCDIC != 1 */
-
    count = 1;
    i = 0;
    if (size > 0) {
@@ -862,14 +812,7 @@ int noimage;
          count++;
          }
       }
-
-#if EBCDIC != 1
    putc(']', f);
-#else					/* EBCDIC != 1 */
-   putc('$', f);
-   putc('>', f);
-#endif					/* EBCDIC != 1 */
-
    }
 
 /*
@@ -1044,7 +987,7 @@ struct b_coexpr *topact(ce)
 struct b_coexpr *ce;
 {
    struct astkblk *abp = ce->es_actstk;
-   
+
 #ifdef MultiThread
    return abp->arec[0].activator;
 #else					/* MultiThread */
@@ -1236,38 +1179,19 @@ int c, q;
       case '\b':			/*	   backspace	*/
          Protect(alcstr("\\b", (word)(2)), return Error);
          return 2;
-
-#if !EBCDIC
       case '\177':			/*      delete	  */
-#else					/* !EBCDIC */
-      case '\x07':			/*      delete    */
-#endif					/* !EBCDIC */
-
          Protect(alcstr("\\d", (word)(2)), return Error);
          return 2;
-
-#if !EBCDIC
       case '\33':			/*	    escape	 */
-#else					/* !EBCDIC */
-      case '\x27':			/*          escape       */
-#endif					/* !EBCDIC */
-
          Protect(alcstr("\\e", (word)(2)), return Error);
          return 2;
       case '\f':			/*	   form feed	*/
          Protect(alcstr("\\f", (word)(2)), return Error);
          return 2;
-
-#if EBCDIC == 1
-      case '\x25':                      /* EBCDIC line feed */
-         Protect(alcstr("\\l", (word)(2)), return Error);
-         return 2;
-#endif					/* EBCDIC */
-
-      case LineFeed:			/*	   new line	*/
+      case '\n':			/*	   new line	*/
          Protect(alcstr("\\n", (word)(2)), return Error);
          return 2;
-      case CarriageReturn:		/*	   return	*/
+      case '\r':			/*	   return	*/
          Protect(alcstr("\\r", (word)(2)), return Error);
          return 2;
       case '\t':			/*	   horizontal tab     */
@@ -1277,7 +1201,7 @@ int c, q;
          Protect(alcstr("\\v", (word)(2)), return Error);
          return 2;
       default:				/*	  hex escape sequence  */
-         sprintf(cbuf, "\\x%02x", ToAscii(c & 0xff));
+         sprintf(cbuf, "\\x%02x", c & 0xff);
          Protect(alcstr(cbuf, (word)(4)), return Error);
          return 4;
       }
@@ -1334,7 +1258,7 @@ dptr dp1, dp2;
             struct b_bignum *blk = &BlkLoc(source)->bignumblk;
 
             slen = blk->lsd - blk->msd;
-            dlen = slen * NB * 0.3010299956639812 	/* 1 / log2(10) */
+            dlen = slen * NB * 0.3010299956639812	/* 1 / log2(10) */
                + log((double)blk->digits[blk->msd]) * 0.4342944819032518 + 0.5;
 							/* 1 / ln(10) */
             if (dlen >= MaxDigits) {
@@ -1417,7 +1341,7 @@ dptr dp1, dp2;
 	       s = ((wbp)(BlkLoc(source)->file.fd))->window->windowlabel;
 	       len = strlen(s);
                Protect (reserve(Strings, (len << 2) + 16), return Error);
-	       sprintf(sbuf, "window_%d:%d(", 
+	       sprintf(sbuf, "window_%d:%d(",
 		       ((wbp)BlkLoc(source)->file.fd)->window->serial,
 		       ((wbp)BlkLoc(source)->file.fd)->context->serial
 		       );
@@ -1552,7 +1476,7 @@ dptr dp1, dp2;
       default:
         if (Type(*dp1) == T_External) {
            /*
-            * For now, just produce "external(n)". 
+            * For now, just produce "external(n)".
             */
            sprintf(sbuf, "external(%ld)", (long)BlkLoc(*dp1)->externl.blksize);
            len = strlen(sbuf);
@@ -1576,10 +1500,9 @@ dptr dp;
    register int n;
 
    n = BlkLoc(*dp)->cset.size;
-   if (n < 0) 
+   if (n < 0)
       n = cssize(dp);
 
-#if EBCDIC != 1
    /*
     * Check for a cset we recognize using a hardwired decision tree.
     *  In ASCII, each of &lcase/&ucase/&digits are complete within 32 bits.
@@ -1606,40 +1529,6 @@ dptr dp;
 	    return "&ascii";
       }
    return NULL;
-#else						/* EBCDIC != 1 */
-   /*
-    * Check for a cset we recognize using a hardwired decision tree.
-    *  In EBCDIC, the neither &lcase nor &ucase is contiguous.
-    *  THIS CODE HAS NOT YET BEEN TESTED.
-    */
-   if (n == 52) {
-      if ((Cset32(0x80,*dp) & Cset32(0xC0,*dp)) == 0x03FE03FE
-         && Cset32(0xA0,*dp) & Cset32(0xE0,*dp)) == 0x03FC)
-	    return ("&letters");
-      }
-   else if (n < 52) {
-      if (n == 26) {
-	 if (Cset32(0x80,*dp) == 0x03FE03FE && Cset32(0xA0,*dp) == 0x03FC)
-	    return ("&lcase");
-	 else if (Cset32(0xC0,*dp) == 0x03FE03FE && Cset32(0xE0,*dp) == 0x03FC)
-	    return ("&ucase");
-	 }
-      else if (n == 10 && *CsetPtr('0',*dp) == (01777 << CsetOff('0')))
-	 return ("&digits");
-      }
-   else /* n > 52 */ {
-      if (n == 256)
-	 return "&cset";
-      else if (n == 128) {
-         int i;
-         for (i = 0; i < CsetSize; i++)
-            if (k_ascii.bits[i] != BlkLoc(*dp)->cset.bits[i])
-               break;
-         if (i >= CsetSize) return "&ascii";
-         }
-      }
-   return NULL;
-#endif						/* EBCDIC != 1 */
    }
 
 /*
@@ -1669,63 +1558,19 @@ dptr dp;
 int printable(c)
 int c;
    {
-
-/*
- * The following code is operating-system dependent [@rmisc.01].
- *  Determine if a character is "printable".
- */
-
-#if PORT
-   return isprint(c);
-Deliberate Syntax Error
-#endif					/* PORT */
-
-#if AMIGA || ATARI_ST || MSDOS || OS2 || UNIX || VMS
    return (isascii(c) && isprint(c));
-#endif					/* AMIGA || ATARI_ST ... */
-
-#if ARM
-   return (c >= 0x00 && c <= 0x7F && isprint(c));
-#endif					/* ARM */
-
-#if MACINTOSH
-#if MPW
-   return (isascii(c) && isprint(c));
-#else					/* MPW */
-   return isprint(c);
-#endif					/* MPW */
-#endif					/* MACINTOSH */
-
-#if MVS || VM
-#if SASC
-   return isascii(c) && !iscntrl(c);
-#else					/* SASC */
-   return isprint(c);
-#endif					/* SASC */
-#endif                                  /* MVS || VM */
-
-/*
- * End of operating-system specific code.
- */
    }
 
-#ifndef AsmOver
 /*
  * add, sub, mul, neg with overflow check
  * all return 1 if ok, 0 if would overflow
  */
 
-/*
- *  Note: on some systems an improvement in performance can be obtained by
- *  replacing the C functions that follow by checks written in assembly
- *  language.  To do so, add #define AsmOver to ../h/define.h.  If your
- *  C compiler supports the asm directive, put the new code at the end
- *  of this section under control of #else.  Otherwise put it a separate
- *  file.
- */
-
 extern int over_flow;
 
+/*
+ * add - integer addition with overflow checking
+ */
 word add(a, b)
 word a, b;
 {
@@ -1739,6 +1584,9 @@ word a, b;
      }
 }
 
+/* 
+ * sub - integer subtraction with overflow checking
+ */
 word sub(a, b)
 word a, b;
 {
@@ -1752,6 +1600,9 @@ word a, b;
       }
 }
 
+/*
+ * mul - integer multiplication with overflow checking
+ */
 word mul(a, b)
 word a, b;
 {
@@ -1772,7 +1623,9 @@ word a, b;
    return a * b;
 }
 
-/* MinLong / -1 overflows; need div3 too */
+/*
+ * mod3 - integer modulo with overflow checking (always rounds to 0)
+ */
 word mod3(a, b)
 word a, b;
 {
@@ -1791,9 +1644,9 @@ word a, b;
 
       default:
 	 /* First, we make b positive */
-      	 if ( b < 0 ) b = -b;	
+	 if ( b < 0 ) b = -b;
 
-	 /* Make sure retval should have the same sign as 'a' */
+	 /* Make sure retval has the same sign as 'a' */
 	 retval = a % b;
 	 if ( ( a < 0 ) && ( retval > 0 ) )
 	    retval -= b;
@@ -1804,6 +1657,9 @@ word a, b;
    return retval;
 }
 
+/*
+ * div3 - integer divide with overflow checking (always rounds to 0)
+ */
 word div3(a, b)
 word a, b;
 {
@@ -1817,8 +1673,9 @@ word a, b;
    return ( a - mod3 ( a, b ) ) / b;
 }
 
-/* MinLong / -1 overflows; need div3 too */
-
+/*
+ * neg - integer negation with overflow checking
+ */
 word neg(a)
 word a;
 {
@@ -1829,7 +1686,6 @@ word a;
    over_flow = 0;
    return -a;
 }
-#endif					/* AsmOver */
 
 #if COMPILER
 /*
@@ -1947,26 +1803,3 @@ word *high;
    if (InRange(low, loc, high))
       deref(valp, valp);
    }
-
-#if MSDOS
-int strcasecmp(char *s1, char *s2)
-{
-   while (*s1 && *s2) {
-      if (tolower(*s1) != tolower(*s2))
-         return tolower(*s1) - tolower(*s2);
-      s1++; s2++;
-      }
-   return tolower(*s1) - tolower(*s2);
-}
-
-int strncasecmp(char *s1, char *s2, int n)
-{
-   int i, j;
-   for(i=0;i<n;i++) {
-      j = tolower(s1[i]) - tolower(s2[i]);
-      if (j) return j;
-      if (s1[i] == '\0') return 0; /* terminate if both at end-of-string */
-      }
-   return 0;
-}
-#endif					/* MSDOS */
